# IT Components in the Reference Catalog
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/it-components-in-reference-catalog#overview)
  * [Benefits](https://help.sap.com/docs/leanix/ea/it-components-in-reference-catalog#benefits)
  * [IT Components in Scope](https://help.sap.com/docs/leanix/ea/it-components-in-reference-catalog#it-components-in-scope)
  * [IT Components Out of Scope](https://help.sap.com/docs/leanix/ea/it-components-in-reference-catalog#it-components-out-of-scope)
  * [Fact Sheet Attributes](https://help.sap.com/docs/leanix/ea/it-components-in-reference-catalog#fact-sheet-attributes)
  * [Vendor Lifecycle Dates](https://help.sap.com/docs/leanix/ea/it-components-in-reference-catalog#vendor-lifecycle-dates)
  * [Configuring Settings for Syncing Fields and Establishing Relations](https://help.sap.com/docs/leanix/ea/it-components-in-reference-catalog#configuring-settings-for-syncing-fields-and-establishing-relations)
  * [Resyncing IT Components](https://help.sap.com/docs/leanix/ea/it-components-in-reference-catalog#resyncing-it-components)


View all
By using reference data for IT component fact sheets, you can increase standardization and data quality, set relations to other fact sheets for best-practice modeling, as well as manage technology obsolescence risks by using vendor lifecycle information.
